==> ants_2.0.0.orig.tar.gz: ants-2.0.0/ImageRegistration/itkANTSAffine3DTransform.h <==
#ifndef __itkANTSAffine3DTransform_h
#define __itkANTSAffine3DTransform_h

#include <iostream>
#include "itkRigid3DTransform.h"
#include "vnl/vnl_quaternion.h"

namespace itk
{
/** \brief ANTSAffine3DTransform of a vector space (e.g. space coordinates).
 *
 * This transform applies a rotation and translation to the space
 *
 * \ingroup Transforms
 */
template <class TScalarType = double>
// Data type for scalars (float or double)
class ANTSAffine3DTransform :
  public         MatrixOffsetTransformBase<TScalarType, 3, 3>
  //        public Rigid3DTransform< TScalarType >
{
public:
  /** Standard class typedefs.   */
  typedef ANTSAffine3DTransform Self;
//  typedef Rigid3DTransform< TScalarType >     Superclass;
  typedef MatrixOffsetTransformBase<TScalarType, 3, 3> Superclass;
  typedef SmartPointer<Self>                           Pointer;
  typedef SmartPointer<const Self>                     ConstPointer;

  /** New macro for creation of through a Smart Pointer   */
  itkNewMacro( Self );

  /** Run-time type information (and related methods).   */
  // itkTypeMacro( ANTSAffine3DTransform, Rigid3DTransform );
  itkTypeMacro( ANTSAffine3DTransform, MatrixOffsetTransformBase );

  /** Dimension of parameters   */
  itkStaticConstMacro(InputSpaceDimension, unsigned int, 3);
  itkStaticConstMacro(OutputSpaceDimension, unsigned int, 3);
  itkStaticConstMacro(SpaceDimension, unsigned int, 3);
  itkStaticConstMacro(ParametersDimension, unsigned int, 13);

  /** Parameters Type   */
  typedef typename Superclass::ParametersType      ParametersType;
  typedef typename Superclass::JacobianType        JacobianType;
  typedef typename Superclass::ScalarType          ScalarType;
  typedef typename Superclass::InputPointType      InputPointType;
  typedef typename Superclass::OutputPointType     OutputPointType;
  typedef typename Superclass::InputVectorType     InputVectorType;
  typedef typename Superclass::OutputVectorType    OutputVectorType;
  typedef typename Superclass::InputVnlVectorType  InputVnlVectorType;
  typedef typename Superclass::OutputVnlVectorType OutputVnlVectorType;
  typedef typename Superclass::InputCovariantVectorType
    InputCovariantVectorType;
  typedef typename Superclass::OutputCovariantVectorType
    OutputCovariantVectorType;
  typedef typename Superclass::MatrixType        MatrixType;
  typedef typename Superclass::InverseMatrixType InverseMatrixType;
  typedef typename Superclass::CenterType        CenterType;
  typedef typename Superclass::OffsetType        OffsetType;
  typedef typename Superclass::TranslationType   TranslationType;

  /** VnlQuaternion type.  */
  typedef vnl_quaternion<TScalarType> VnlQuaternionType;

  /** Compute the Jacobian Matrix of the transformation at one point */
  /** Set the rotation of the rigid transform.
   * This method sets the rotation of a ANTSAffine3DTransform to a
   * value specified by the user. */
  void SetRotation(const VnlQuaternionType & rotation);

  void SetS1(const TScalarType S1);

  void SetS2(const TScalarType S2);

  void SetS3(const TScalarType S3);

  void SetK1(const TScalarType K1);

  void SetK2(const TScalarType K2);

  void SetK3(const TScalarType K3);

  /** Get the rotation from an ANTSAffine3DTransform.
   * This method returns the value of the rotation of the
   * ANTSAffine3DTransform.   **/
  const VnlQuaternionType & GetRotation(void) const
  {
    return m_Rotation;
  }

  MatrixType ComputeMyRotationMatrix();

  itkGetConstReferenceMacro( S1, TScalarType );
  itkGetConstReferenceMacro( S2, TScalarType );
  itkGetConstReferenceMacro( S3, TScalarType );
  itkGetConstReferenceMacro( K1, TScalarType );
  itkGetConstReferenceMacro( K2, TScalarType );
  itkGetConstReferenceMacro( K3, TScalarType );

  /** Set the parameters to the IdentityTransform */
  virtual void SetIdentity(void);

  /** Set the transformation from a container of parameters.
   * This is typically used by optimizers.
   * There are 7 parameters. The first four represents the
   * quaternion and the last three represents the
   * offset. */
  void SetParameters( const ParametersType & parameters );

  const ParametersType & GetParameters() const;

//  /** Compute the Jacobian of the transformation.
//   * This method computes the Jacobian matrix of the transformation.
//   * given point or vector, returning the transformed point or
//   * vector. The rank of the Jacobian will also indicate if the transform
//   * is invertible at this point. */
//  const JacobianType & GetJacobian(const InputPointType  &point ) const;

  /** Compute the Jacobian of the transformation
 *
 * This method computes the Jacobian matrix of the transformation.
 * given point or vector, returning the transformed point or
 * vector. The rank of the Jacobian will also indicate if the transform
 * is invertible at this point.
 * Get local Jacobian for the given point
 * \c j will sized properly as needed.
 */
  virtual void ComputeJacobianWithRespectToParameters(const InputPointType  & p, JacobianType & j) const;

protected:
/*   ANTSAffine3DTransform(const MatrixType &matrix, */
/*                            const OutputVectorType &offset); */
  ANTSAffine3DTransform(unsigned int outputDims, unsigned int paramDims);
  ANTSAffine3DTransform();
  ~ANTSAffine3DTransform()
  {
  };

  virtual void ComputeMatrix();

  virtual void ComputeMatrixParameters();

  void SetVarRotation(const VnlQuaternionType & rotation)
  {
    m_Rotation = rotation;
  };

//  const InverseMatrixType & GetInverseMatrix( void ) const;

  void PrintSelf(std::ostream & os, Indent indent) const;

private:
  ANTSAffine3DTransform(const Self &); // purposely not implemented
  void operator=(const Self &);        // purposely not implemented

  /** Rotation of the transformation. */
  VnlQuaternionType m_Rotation;

  /** added affine parameters **/
  TScalarType m_S1;
  TScalarType m_S2;
  TScalarType m_S3;
  TScalarType m_K1;
  TScalarType m_K2;
  TScalarType m_K3;
}; // class ANTSAffine3DTransform
}  // namespace itk

#ifndef ITK_MANUAL_INSTANTIATION
#include "itkANTSAffine3DTransform.hxx"
#endif

#endif /* __itkANTSAffine3DTransform_h */

==> ants_2.2.0.orig.tar.gz: ants-2.2.0/ImageRegistration/itkANTSAffine3DTransform.h <==
#ifndef __itkANTSAffine3DTransform_h
#define __itkANTSAffine3DTransform_h

#include <iostream>
#include "itkRigid3DTransform.h"
#include "vnl/vnl_quaternion.h"

namespace itk
{
/** \brief ANTSAffine3DTransform of a vector space (e.g. space coordinates).
 *
 * This transform applies a rotation and translation to the space
 *
 * \ingroup Transforms
 */
template <class TScalarType = double>
// Data type for scalars (float or double)
class ANTSAffine3DTransform :
  public         MatrixOffsetTransformBase<TScalarType, 3, 3>
  //        public Rigid3DTransform< TScalarType >
{
public:
  /** Standard class typedefs.   */
  typedef ANTSAffine3DTransform Self;
//  typedef Rigid3DTransform< TScalarType >     Superclass;
  typedef MatrixOffsetTransformBase<TScalarType, 3, 3> Superclass;
  typedef SmartPointer<Self>                           Pointer;
  typedef SmartPointer<const Self>                     ConstPointer;

  /** New macro for creation of through a Smart Pointer   */
  itkNewMacro( Self );

  /** Run-time type information (and related methods).   */
  // itkTypeMacro( ANTSAffine3DTransform, Rigid3DTransform );
  itkTypeMacro( ANTSAffine3DTransform, MatrixOffsetTransformBase );

  /** Dimension of parameters   */
  itkStaticConstMacro(InputSpaceDimension, unsigned int, 3);
  itkStaticConstMacro(OutputSpaceDimension, unsigned int, 3);
  itkStaticConstMacro(SpaceDimension, unsigned int, 3);
  itkStaticConstMacro(ParametersDimension, unsigned int, 13);

  /** Parameters Type   */
  typedef typename Superclass::ParametersType      ParametersType;
  typedef typename Superclass::JacobianType        JacobianType;
  typedef typename Superclass::ScalarType          ScalarType;
  typedef typename Superclass::InputPointType      InputPointType;
  typedef typename Superclass::OutputPointType     OutputPointType;
  typedef typename Superclass::InputVectorType     InputVectorType;
  typedef typename Superclass::OutputVectorType    OutputVectorType;
  typedef typename Superclass::InputVnlVectorType  InputVnlVectorType;
  typedef typename Superclass::OutputVnlVectorType OutputVnlVectorType;
  typedef typename Superclass::InputCovariantVectorType
    InputCovariantVectorType;
  typedef typename Superclass::OutputCovariantVectorType
    OutputCovariantVectorType;
  typedef typename Superclass::MatrixType        MatrixType;
  typedef typename Superclass::InverseMatrixType InverseMatrixType;
  typedef typename Superclass::CenterType        CenterType;
  typedef typename Superclass::OffsetType        OffsetType;
  typedef typename Superclass::TranslationType   TranslationType;

  /** VnlQuaternion type.  */
  typedef vnl_quaternion<TScalarType> VnlQuaternionType;

  /** Compute the Jacobian Matrix of the transformation at one point */
  /** Set the rotation of the rigid transform.
   * This method sets the rotation of a ANTSAffine3DTransform to a
   * value specified by the user. */
  void SetRotation(const VnlQuaternionType & rotation);

  void SetS1(const TScalarType S1);

  void SetS2(const TScalarType S2);

  void SetS3(const TScalarType S3);

  void SetK1(const TScalarType K1);

  void SetK2(const TScalarType K2);

  void SetK3(const TScalarType K3);

  /** Get the rotation from an ANTSAffine3DTransform.
   * This method returns the value of the rotation of the
   * ANTSAffine3DTransform.   **/
  const VnlQuaternionType & GetRotation() const
  {
    return m_Rotation;
  }

  MatrixType ComputeMyRotationMatrix();

  itkGetConstReferenceMacro( S1, TScalarType );
  itkGetConstReferenceMacro( S2, TScalarType );
  itkGetConstReferenceMacro( S3, TScalarType );
  itkGetConstReferenceMacro( K1, TScalarType );
  itkGetConstReferenceMacro( K2, TScalarType );
  itkGetConstReferenceMacro( K3, TScalarType );

  /** Set the parameters to the IdentityTransform */
  virtual void SetIdentity() ITK_OVERRIDE;

  /** Set the transformation from a container of parameters.
   * This is typically used by optimizers.
   * There are 7 parameters. The first four represents the
   * quaternion and the last three represents the
   * offset. */
  void SetParameters( const ParametersType & parameters ) ITK_OVERRIDE;

  const ParametersType & GetParameters() const ITK_OVERRIDE;

//  /** Compute the Jacobian of the transformation.
//   * This method computes the Jacobian matrix of the transformation.
//   * given point or vector, returning the transformed point or
//   * vector. The rank of the Jacobian will also indicate if the transform
//   * is invertible at this point. */
//  const JacobianType & GetJacobian(const InputPointType  &point ) const;

  /** Compute the Jacobian of the transformation
 *
 * This method computes the Jacobian matrix of the transformation.
 * given point or vector, returning the transformed point or
 * vector. The rank of the Jacobian will also indicate if the transform
 * is invertible at this point.
 * Get local Jacobian for the given point
 * \c j will sized properly as needed.
 */
  virtual void ComputeJacobianWithRespectToParameters(const InputPointType  & p, JacobianType & j) const ITK_OVERRIDE;

protected:
/*   ANTSAffine3DTransform(const MatrixType &matrix, */
/*                            const OutputVectorType &offset); */
  ANTSAffine3DTransform(unsigned int outputDims, unsigned int paramDims);
  ANTSAffine3DTransform();
  ~ANTSAffine3DTransform()
  {
  };

  virtual void ComputeMatrix() ITK_OVERRIDE;

  virtual void ComputeMatrixParameters() ITK_OVERRIDE;

  void SetVarRotation(const VnlQuaternionType & rotation)
  {
    m_Rotation = rotation;
  };

//  const InverseMatrixType & GetInverseMatrix() const;

  void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;

private:
  ANTSAffine3DTransform(const Self &); // purposely not implemented
  void operator=(const Self &);        // purposely not implemented

  /** Rotation of the transformation. */
  VnlQuaternionType m_Rotation;

  /** added affine parameters **/
  TScalarType m_S1;
  TScalarType m_S2;
  TScalarType m_S3;
  TScalarType m_K1;
  TScalarType m_K2;
  TScalarType m_K3;
}; // class ANTSAffine3DTransform
}  // namespace itk

#ifndef ITK_MANUAL_INSTANTIATION
#include "itkANTSAffine3DTransform.hxx"
#endif

#endif /* __itkANTSAffine3DTransform_h */
